LinkTag class

Inheritance

Constructors

LinkTag({String? title, String? rel, String? type, String? hreflang, String? href, String? media})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
href → String?
final
hreflang → String?
final
media → String?
final
rel → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited